@@ -24,12 +24,12 @@ def _servers():
     return res
 
 @cache
-def _schema():
-    return cfg_read().get('sql_schema', 'dbo')
+def _schema(schema = None):
+    return schema or cfg_read().get('sql_schema', 'dbo')
 
 @cache
-def _database():
-    return cfg_read().get('sql_database', 'master')
+def _database(db = None):
+    return db or cfg_read().get('sql_database', 'master')
 
     
 def get_server(server = None):
@@ -39,6 +39,7 @@ def get_server(server = None):
         config['sql_server'] = dict(dev = 'server.test', prod = 'prod.server')
     """
     servers = _servers()
+    server = server or None
     if isinstance(servers, str):
         if server is None or server is True:
             server = servers
@@ -87,7 +88,7 @@ def _pairs2connection(*pairs, **connection):
 def _db(connection):
     db = connection.pop('db', None)
     if db is None:
-        db = connection.pop('database', _database())
+        db = _database(connection.pop('database', None))
     return db
     
 def get_cstr(*pairs, **connection):
@@ -225,7 +226,7 @@ def sql_table(table, db = None, non_null = None, nullable = None, _id = None, sc
         table_name = table.name
         if schema is None:
             schema = table.schema
-    schema = create_schema(e, schema or _schema())
+    schema = create_schema(e, _schema(schema))
     if doc is True:
         doc = _doc
     meta = MetaData()
@@ -718,7 +719,15 @@ class sql_cursor(object):
             return self.select(ulist(as_list(self.selection)) - other)
         else:
             raise ValueError('cannot subtract these columns while the selection is non empty, use self.select() to reset selection')
-                
+    
+    def drop(self):
+        logger.info('dropping table: %s.%s.%s'%(self.db, 
+                                                  self.schema, 
+                                                  self.table.name))
+
+        self.table.drop(bind = self.engine)
+
+    
     def exc(self, *args, **kwargs):
         """
         Exclude: This returns a table with additional filtering OPPOSITE TO inc. note that you can build it iteratively
@@ -1208,7 +1217,7 @@ class sql_cursor(object):
                 self.deleted.insert_many(docs, write = False)
             res.full_delete()
         return self
-        
+
     def sort(self, order = None):
         if not order:
             return self
@@ -1285,6 +1294,6 @@ class sql_cursor(object):
             A unique combination of the server address, db name and table name, identifying the table uniquely. This allows us to create an in-memory representation of the data in pyg-cell
 
         """
-        return ('server', self.server or get_server()), ('db', self.db), ('table', self.table.name)
+        return ('server', self.server or get_server()), ('db', self.db), ('schema', self.schema), ('table', self.table.name)
 
 
